@@ -9,6 +9,8 @@ __email__ = "jake.nunemaker@nrel.gov"
 from abc import ABC, abstractmethod
 from copy import deepcopy
 
+from benedict import benedict
+
 from ORBIT.core.library import initialize_library, extract_library_data
 from ORBIT.core.exceptions import MissingInputs
 
@@ -115,7 +117,7 @@ class BasePhase(ABC):
             raise MissingInputs(missing)
 
         else:
-            return config
+            return benedict(config)
 
     @abstractmethod
     def run(self):
